﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Windows.DataPresenter;

namespace ComboItemBinding
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DataContext = new MainViewModel();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {            
            InfoWindow info = new InfoWindow(((sender as Button).DataContext as DataRecord).DataItem as Patient, DataContext as MainViewModel);
            info.ShowDialog();
        }
    }

    public class MainViewModel : ViewModelBase
    {
        public MainViewModel()
        {
            Clinics = Clinic.SelfListAll();
            Patients = new ObservableCollection<Patient>();
            Random r = new Random();

            for (int i = 0; i < 10; i++)
            {
                Patients.Add(new Patient { ID = i, Name = "Pt 1", Age = i * i, Clinic = Clinics[r.Next(Clinics.Count)] });
            }
        }


        private ObservableCollection<Patient> patients;

        public ObservableCollection<Patient> Patients
        {
            get { return patients; }
            set { patients = value; OnPropChanged("Patients"); }
        }

        private ObservableCollection<Clinic> clinics;

        public ObservableCollection<Clinic> Clinics
        {
            get { return clinics; }
            set { clinics = value; OnPropChanged("Clinics"); }
        }

    }

    public class Clinic : ViewModelBase
    {
        private int clinicID;

        public int ClinicID
        {
            get { return clinicID; }
            set { clinicID = value; OnPropChanged("ClinicID"); }
        }

        private string name;

        public string Name
        {
            get { return name; }
            set { name = value; OnPropChanged("Name"); }
        }


        public override bool Equals(object obj)
        {
            if (obj is Clinic)
            {
                return (obj as Clinic).ClinicID == ClinicID;
            }
            return false;
        }

        public static ObservableCollection<Clinic> SelfListAll()
        {
            ObservableCollection<Clinic> data = new ObservableCollection<Clinic>();

            for (int i = 0; i < 10; i++)
            {
                data.Add(new Clinic { Name = "Clininc " + i, ClinicID = i });
            }

            return data;
        }


        
    }

    public class Patient : ViewModelBase
    {

        private int id;

        public int ID
        {
            get { return id; }
            set { id = value; OnPropChanged("ID"); }
        }

        private string fName;

        public string Name
        {
            get { return fName; }
            set { fName = value; OnPropChanged("FirstName"); }
        }

        private int age;

        public int Age
        {
            get { return age; }
            set { age = value; OnPropChanged("LastName"); }
        }

        private Clinic clinic;

        public Clinic Clinic
        {
            get { return clinic; }
            set { clinic = value; OnPropChanged("Clinic"); }
        }
    }

    public class ViewModelBase : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropChanged(string s)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(s));
        }
    }

}
